@@ -1,9 +1,4 @@
 # frozen_string_literal: true
-# Psych could be a gem, so try to ask for it
-begin
-  gem "psych"
-rescue LoadError
-end if defined?(gem)
 
 # Psych could be in the stdlib
 # but it's too late if Syck is already loaded
